/* eslint-disable no-console */
import { writeFileSync } from "node:fs";
import { DEFAULT_CONFIG_FILE, DEFAULT_CONFIG_FILE_RAW, loadPgTConfig } from "@postgresql-typed/util";
import debug from "debug";
import { join, resolve } from "pathe";
import { g, y } from "../util/chalk.js";
import { GLOBAL_DEBUG_GLOB, LOGGER } from "../util/constants.js";
import { getConsoleHeader } from "../util/functions/getters/getConsoleHeader.js";
export class ConfigHandler {
    constructor() {
        this.filepath = null;
        this.config = {};
        this.LOGGER = LOGGER?.extend("ConfigHandler");
    }
    async loadConfig() {
        this.LOGGER?.("Loading config file...");
        //TODO allow passing config file path
        const result = await loadPgTConfig();
        if (!result.configFile) {
            this.LOGGER?.("No config file found");
            return this;
        }
        this.LOGGER?.("Config file loaded");
        this.config = result.config.cli;
        if (this.config.files.debug) {
            debug.enable(GLOBAL_DEBUG_GLOB);
            this.LOGGER?.("Debug mode enabled at a later point, to enable it earlier, use the --debug flag");
        }
        return this;
    }
    async initConfig() {
        this.LOGGER?.("Initializing config file...");
        const result = await loadPgTConfig();
        if (result?.configFile && result?.cwd) {
            this.LOGGER?.("Config file already exists");
            console.log(getConsoleHeader(y("A configuration file is already present, skipping initialization..."), `File location: ${resolve(result.cwd, result.configFile)}`));
            return 0;
        }
        try {
            const location = join(process.cwd(), DEFAULT_CONFIG_FILE);
            this.LOGGER?.("Writing config file to", location);
            writeFileSync(location, DEFAULT_CONFIG_FILE_RAW);
            console.log(getConsoleHeader(g("Successfully created configuration file!"), `File location: ${location}`));
            return 0;
        }
        catch (error) {
            console.error(error);
            return 1;
        }
    }
    get connections() {
        if (Array.isArray(this.config.connections))
            return this.config.connections;
        return [this.config.connections];
    }
}
//# sourceMappingURL=ConfigHandler.js.map